==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-registry/nifi-registry-core/nifi-registry-framework/src/main/java/org/apache/nifi/registry/service/extension/docs/ExtensionDocWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.registry.service.extension.docs;

import org.apache.nifi.extension.ExtensionMetadata;
import org.apache.nifi.extension.manifest.Extension;

import java.io.IOException;
import java.io.OutputStream;

public interface ExtensionDocWriter {

    /**
     * Generates the documentation for the given Extension and writes it to the given OutputStream.
     *
     * @param extensionMetadata the metadata for the extension
     * @param extension the extension descriptor
     * @param outputStream the output stream to write the docs to
     * @throws IOException if an error occurs writing the documentation to the given output stream
     */
    void write(ExtensionMetadata extensionMetadata, Extension extension, OutputStream outputStream) throws IOException;

}

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-registry/nifi-registry-core/nifi-registry-framework/src/main/java/org/apache/nifi/registry/service/extension/docs/ExtensionDocWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.registry.service.extension.docs;

import org.apache.nifi.extension.manifest.Extension;
import org.apache.nifi.registry.extension.component.ExtensionMetadata;

import java.io.IOException;
import java.io.OutputStream;

public interface ExtensionDocWriter {

    /**
     * Generates the documentation for the given Extension and writes it to the given OutputStream.
     *
     * @param extensionMetadata the metadata for the extension
     * @param extension the extension descriptor
     * @param outputStream the output stream to write the docs to
     * @throws IOException if an error occurs writing the documentation to the given output stream
     */
    void write(ExtensionMetadata extensionMetadata, Extension extension, OutputStream outputStream) throws IOException;

}
